# SubmitDataQueryRequestCompression

Specifies whether Zuora compresses the query results. 

## Enum

* `NONE` (value: `'NONE'`)

* `GZIP` (value: `'GZIP'`)

* `ZIP` (value: `'ZIP'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


